==> tigl3_3.0.0~rc1.orig.tar.gz: tigl-3.0.0rc1/src/cpacs_other/CCPACSAircraftModel.cpp <==
/* 
* Copyright (C) 2014 Airbus Defense and Space
*
* Created: 2014-09-19 Roland Landertshamer <roland.landertshamer@risc-software.at>
* Changed: $Id: CCPACSAircraftModel.cpp 1434 2016-04-15 15:41:53Z rlandert $ 
*
* Version: $Revision: 1434 $
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
/**
* @file 
* @brief  Implementation of Model for use as root component in CTiglUIDManager
*/

#include "CCPACSAircraftModel.h"

#include "CCPACSConfiguration.h"

namespace tigl
{
CCPACSAircraftModel::CCPACSAircraftModel(CCPACSConfiguration* config)
    : generated::CPACSAircraftModel(config ? &config->GetUIDManager() : NULL), CTiglRelativelyPositionedComponent(NULL, NULL), config(config) {}

CCPACSAircraftModel::CCPACSAircraftModel(CTiglUIDManager* uidMgr)
    : generated::CPACSAircraftModel(uidMgr), CTiglRelativelyPositionedComponent(NULL, NULL), config(NULL) {}

void CCPACSAircraftModel::ReadCPACS(const TixiDocumentHandle& tixiHandle, const std::string& xpath) {
    generated::CPACSAircraftModel::ReadCPACS(tixiHandle, xpath);
    if (m_uidMgr) {
        m_uidMgr->AddGeometricComponent(m_uID, this);
    }
}

void CCPACSAircraftModel::SetUID(const std::string& uid) {
    if (m_uidMgr) {
        m_uidMgr->TryRemoveGeometricComponent(m_uID);
        m_uidMgr->AddGeometricComponent(uid, this);
    }
    generated::CPACSAircraftModel::SetUID(uid);
}

std::string CCPACSAircraftModel::GetDefaultedUID() const {
    return generated::CPACSAircraftModel::GetUID();
}

// Returns the Geometric type of this component, e.g. Wing or Fuselage
TiglGeometricComponentType CCPACSAircraftModel::GetComponentType() const
{
    return (TIGL_COMPONENT_PHYSICAL | TIGL_COMPONENT_PLANE);
}

PNamedShape CCPACSAircraftModel::BuildLoft()
{
    // return empty loft
    return loft;
}

void CCPACSAircraftModel::Invalidate() {
    if (m_wings)
        m_wings->Invalidate();
    if (m_fuselages)
        m_fuselages->Invalidate();
}

CCPACSConfiguration& CCPACSAircraftModel::GetConfiguration() const {
    return *config;
}

} // end namespace tigl

==> tigl3_3.2.3.orig.tar.gz: tigl-3.2.3/src/cpacs_other/CCPACSAircraftModel.cpp <==
/* 
* Copyright (C) 2014 Airbus Defense and Space
*
* Created: 2014-09-19 Roland Landertshamer <roland.landertshamer@risc-software.at>
* Changed: $Id: CCPACSAircraftModel.cpp 1434 2016-04-15 15:41:53Z rlandert $ 
*
* Version: $Revision: 1434 $
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
/**
* @file 
* @brief  Implementation of Model for use as root component in CTiglUIDManager
*/

#include "CCPACSAircraftModel.h"

#include "CCPACSConfiguration.h"

namespace tigl
{
CCPACSAircraftModel::CCPACSAircraftModel(CCPACSConfiguration* config)
    : generated::CPACSAircraftModel(nullptr, config ? &config->GetUIDManager() : NULL), CTiglRelativelyPositionedComponent(static_cast<std::string*>(NULL), NULL), config(config) {}

CCPACSAircraftModel::CCPACSAircraftModel(CCPACSAircraft* parent, CTiglUIDManager* uidMgr)
    : generated::CPACSAircraftModel(parent, uidMgr), CTiglRelativelyPositionedComponent(static_cast<std::string*>(NULL), NULL), config(NULL) {}

std::string CCPACSAircraftModel::GetDefaultedUID() const {
    return generated::CPACSAircraftModel::GetUID();
}

// Returns the Geometric type of this component, e.g. Wing or Fuselage
TiglGeometricComponentType CCPACSAircraftModel::GetComponentType() const
{
    return TIGL_COMPONENT_PLANE;
}

TiglGeometricComponentIntent CCPACSAircraftModel::GetComponentIntent() const
{
    return TIGL_INTENT_PHYSICAL;
}


PNamedShape CCPACSAircraftModel::BuildLoft() const
{
    return PNamedShape();
}


CCPACSConfiguration& CCPACSAircraftModel::GetConfiguration() const {
    return *config;
}

} // end namespace tigl
